@@ -588,6 +588,7 @@ build_header_response (struct MHD_Connection *connection)
   char *data;
   enum MHD_ValueKind kind;
   const char *reason_phrase;
+  uint32_t rc;
 
   EXTRA_CHECK (NULL != connection->version);
   if (0 == strlen(connection->version))
@@ -602,14 +603,17 @@ build_header_response (struct MHD_Connection *connection)
   if (connection->state == MHD_CONNECTION_FOOTERS_RECEIVED)
     {
       add_extra_headers (connection);
-      reason_phrase = MHD_get_reason_phrase_for (connection->responseCode);
+      rc = connection->responseCode & (~MHD_ICY_FLAG);
+      reason_phrase = MHD_get_reason_phrase_for (rc);
       SPRINTF (code,
                "%s %u %s\r\n",
-               (0 == strcasecmp (MHD_HTTP_VERSION_1_0,
-				 connection->version)) 
-	       ? MHD_HTTP_VERSION_1_0 
-	       : MHD_HTTP_VERSION_1_1,
-	       connection->responseCode, 
+	       (0 != (connection->responseCode & MHD_ICY_FLAG))
+	       ? "ICY" 
+	       : ( (0 == strcasecmp (MHD_HTTP_VERSION_1_0,
+				     connection->version)) 
+		   ? MHD_HTTP_VERSION_1_0 
+		   : MHD_HTTP_VERSION_1_1),
+	       rc, 
 	       reason_phrase);
       off = strlen (code);
       /* estimate size */
@@ -763,7 +767,7 @@ MHD_connection_get_fdset (struct MHD_Connection *connection,
  *                 connection is not waiting for any read or write events
  */
 int
-MHD_connection_get_pollfd(struct MHD_Connection *connection, struct MHD_Pollfd *p)
+MHD_connection_get_pollfd (struct MHD_Connection *connection, struct MHD_Pollfd *p)
 {
   int fd;
 
@@ -1643,6 +1647,7 @@ parse_connection_headers (struct MHD_Connection *connection)
                 "Received `%s' request without `%s' header.\n",
                 MHD_HTTP_VERSION_1_1, MHD_HTTP_HEADER_HOST);
 #endif
+      EXTRA_CHECK (connection->response == NULL);
       response =
         MHD_create_response_from_data (strlen (REQUEST_LACKS_HOST),
                                        REQUEST_LACKS_HOST, MHD_NO, MHD_NO);
@@ -2259,7 +2264,7 @@ MHD_connection_handle_idle (struct MHD_Connection *connection)
 }
 
 void
-MHD_set_http_calbacks (struct MHD_Connection *connection)
+MHD_set_http_callbacks_ (struct MHD_Connection *connection)
 {
   connection->read_handler = &MHD_connection_handle_read;
   connection->write_handler = &MHD_connection_handle_write;
