@@ -58,6 +58,11 @@ ahc_echo (void *cls,
     return MHD_NO;
   sprintf (me, fmt, "q", val);
   response = MHD_create_response_from_data (strlen (me), me, MHD_YES, MHD_NO);
+  if (response == NULL)
+    {
+      free (me);
+      return MHD_NO;
+    }
   ret = MHD_queue_response (connection, MHD_HTTP_OK, response);
   MHD_destroy_response (response);
   return ret;
@@ -68,9 +73,9 @@ main (int argc, char *const *argv)
 {
   struct MHD_Daemon *d;
 
-  if (argc != 3)
+  if (argc != 2)
     {
-      printf ("%s PORT SECONDS-TO-RUN\n", argv[0]);
+      printf ("%s PORT\n", argv[0]);
       return 1;
     }
   d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_DEBUG,
@@ -78,7 +83,7 @@ main (int argc, char *const *argv)
                         NULL, NULL, &ahc_echo, PAGE, MHD_OPTION_END);
   if (d == NULL)
     return 1;
-  sleep (atoi (argv[2]));
+  (void) getc (stdin);
   MHD_stop_daemon (d);
   return 0;
 }
