@@ -94,15 +94,19 @@ extern "C"
 #include <unistd.h>
 #include <stdarg.h>
 #include <stdint.h>
+#ifdef __MINGW32__
+#include <ws2tcpip.h>
+#else
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #endif
+#endif
 
 /**
  * Current version of the library.
  */
-#define MHD_VERSION 0x00090000
+#define MHD_VERSION 0x00090200
 
 /**
  * MHD-internal return code for "YES".
@@ -190,6 +194,13 @@ extern "C"
 #define MHD_HTTP_BANDWIDTH_LIMIT_EXCEEDED 509
 #define MHD_HTTP_NOT_EXTENDED 510
 
+/**
+ * Flag to be "OR"ed with MHD_HTTP status code for
+ * SHOUTcast.  This will cause the response to begin
+ * with the SHOUTcast "ICY" line instad of "HTTP".
+ */ 
+#define MHD_ICY_FLAG ((uint32_t)(1 << 31))
+
 /* See also: http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html */
 #define MHD_HTTP_HEADER_ACCEPT "Accept"
 #define MHD_HTTP_HEADER_ACCEPT_CHARSET "Accept-Charset"
@@ -855,6 +866,8 @@ typedef int
  *        libmicrohttpd guarantees that "pos" will be
  *        the sum of all non-negative return values
  *        obtained from the content reader so far.
+ * @param buf where to copy the data
+ * @param max maximum number of bytes to copy to buf (size of buf)
  * @return -1 for the end of transmission (or on error);
  *  if a content transfer size was pre-set and the callback
  *  has provided fewer than that amount of data,
@@ -865,11 +878,11 @@ typedef int
  *  (possibly allowing the client to perform additional
  *  requests using the same TCP connection).
  */
-typedef int
+typedef ssize_t
   (*MHD_ContentReaderCallback) (void *cls,
 				uint64_t pos,
 				char *buf,
-				int max);
+				size_t max);
 
 /**
  * This method is called by libmicrohttpd if we
@@ -926,7 +939,7 @@ typedef int
  * @return NULL on error, handle to daemon on success
  */
 struct MHD_Daemon *MHD_start_daemon_va (unsigned int options,
-                                        unsigned short port,
+                                        uint16_t port,
                                         MHD_AcceptPolicyCallback apc,
                                         void *apc_cls,
                                         MHD_AccessHandlerCallback dh,
@@ -948,7 +961,7 @@ struct MHD_Daemon *MHD_start_daemon_va (unsigned int options,
  * @return NULL on error, handle to daemon on success
  */
 struct MHD_Daemon *MHD_start_daemon (unsigned int flags,
-                                     unsigned short port,
+                                     uint16_t port,
                                      MHD_AcceptPolicyCallback apc,
                                      void *apc_cls,
                                      MHD_AccessHandlerCallback dh,
